@@ -46,7 +46,7 @@ class IgnoredTracerContext(AbstractTracerContext):
     def stop_span(self, span):
         self.stack_depth -= 1
         if self.stack_depth == 0:
-            IgnoredListenerManager.notifyFinish(self)
+            IgnoredListenerManager.notify_finish(self)
 
     def await_finish_async(self):
         pass
