@@ -23,19 +23,16 @@ def trace_flask_request(f):
             context_carrier = ContextCarrier()
             context_carrier.deserialize(sw6)
         entry_span = ContextManager.create_entry_span(req.path, context_carrier)
-        if entry_span:
-            set_tag_url(entry_span, req.url)
-            set_tag_method(entry_span, req.method)
-            set_layer_http(entry_span)
-            set_component(entry_span, FLASK)
+        set_tag_url(entry_span, req.url)
+        set_tag_method(entry_span, req.method)
+        set_layer_http(entry_span)
+        set_component(entry_span, FLASK)
         try:
             return f(*args, **kwargs)
         except BaseException as ex:
-            if entry_span:
-                entry_span.log(ex)
+            entry_span.log(ex)
         finally:
-            if entry_span:
-                ContextManager.stop_span(entry_span)
+            ContextManager.stop_span(entry_span)
 
     return decorated_function
 
@@ -52,44 +49,24 @@ def trace_request_started(sender, **extra):
         context_carrier = ContextCarrier()
         context_carrier.deserialize(sw6)
     entry_span = ContextManager.create_entry_span(req.path, context_carrier)
-    if entry_span:
-        set_tag_url(entry_span, req.url)
-        set_tag_method(entry_span, req.method)
-        set_layer_http(entry_span)
-        set_component(entry_span, FLASK)
+    set_tag_url(entry_span, req.url)
+    set_tag_method(entry_span, req.method)
+    set_layer_http(entry_span)
+    set_component(entry_span, FLASK)
 
 
-
-# def trace_request_finished(sender, response, **extra):
-#     try:
-#         import flask
-#     except ImportError:
-#         return
-#     try:
-#         span = ContextManager.active_span()
-#         ContextManager.stop_span(span)
-#     except SkywalkingException as ex:
-#         return
-
-
-def trace_request_exception(exception):
+def trace_request_exception(exception=None):
     try:
         import flask
     except ImportError:
-        return
-
+        pass
     try:
         span = ContextManager.active_span()
-        if span is not None and exception is not None:
+        if exception is not None:
             span.log(exception)
-            ContextManager.stop_span(span)
-            raise exception
-
-        if span is not None:
-            ContextManager.stop_span(span)
+        ContextManager.stop_span(span)
     except SkywalkingException as ex:
-        return
-
+        pass
 
 
 def flask_install(app):
@@ -98,7 +75,5 @@ def flask_install(app):
     except ImportError:
         return
     from flask import request_started
-    from flask import request_finished
     request_started.connect(trace_request_started, app)
-    # request_finished.connect(trace_request_finished, app)
     app.teardown_request(trace_request_exception)
